import typing

import java
import java.chaquopy
import java.lang
import java.util
import org.xml.sax

class AttributeListImpl(org.xml.sax.AttributeList):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, atts: org.xml.sax.AttributeList, /) -> None: ...
    def addAttribute(self, name: str | java.lang.String, type: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def clear(self) -> None: ...
    def getLength(self) -> int: ...
    def getName(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getType(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getType(self, name: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getValue(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getValue(self, name: str | java.lang.String, /) -> str: ...
    def removeAttribute(self, name: str | java.lang.String, /) -> None: ...
    def setAttributeList(self, atts: org.xml.sax.AttributeList, /) -> None: ...

class AttributesImpl(org.xml.sax.Attributes):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, atts: org.xml.sax.Attributes, /) -> None: ...
    def addAttribute(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, type: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def clear(self) -> None: ...
    @typing.overload
    def getIndex(self, qName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def getIndex(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> int: ...
    def getLength(self) -> int: ...
    def getLocalName(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getQName(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getType(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getType(self, qName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getType(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> str: ...
    def getURI(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getValue(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getValue(self, qName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getValue(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> str: ...
    def removeAttribute(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAttribute(self, index: int | java.jint | java.lang.Integer, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, type: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setAttributes(self, atts: org.xml.sax.Attributes, /) -> None: ...
    def setLocalName(self, index: int | java.jint | java.lang.Integer, localName: str | java.lang.String, /) -> None: ...
    def setQName(self, index: int | java.jint | java.lang.Integer, qName: str | java.lang.String, /) -> None: ...
    def setType(self, index: int | java.jint | java.lang.Integer, type: str | java.lang.String, /) -> None: ...
    def setURI(self, index: int | java.jint | java.lang.Integer, uri: str | java.lang.String, /) -> None: ...
    def setValue(self, index: int | java.jint | java.lang.Integer, value: str | java.lang.String, /) -> None: ...

class DefaultHandler(org.xml.sax.ContentHandler, org.xml.sax.DTDHandler, org.xml.sax.EntityResolver, org.xml.sax.ErrorHandler):
    def __init__(self) -> None: ...
    def characters(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def endDocument(self) -> None: ...
    def endElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, /) -> None: ...
    def endPrefixMapping(self, prefix: str | java.lang.String, /) -> None: ...
    def error(self, e: org.xml.sax.SAXParseException, /) -> None: ...
    def fatalError(self, e: org.xml.sax.SAXParseException, /) -> None: ...
    def ignorableWhitespace(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def notationDecl(self, name: str | java.lang.String, publicId: str | java.lang.String, systemId: str | java.lang.String, /) -> None: ...
    def processingInstruction(self, target: str | java.lang.String, data: str | java.lang.String, /) -> None: ...
    def resolveEntity(self, publicId: str | java.lang.String, systemId: str | java.lang.String, /) -> org.xml.sax.InputSource: ...
    def setDocumentLocator(self, locator: org.xml.sax.Locator, /) -> None: ...
    def skippedEntity(self, name: str | java.lang.String, /) -> None: ...
    def startDocument(self) -> None: ...
    def startElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, attributes: org.xml.sax.Attributes, /) -> None: ...
    def startPrefixMapping(self, prefix: str | java.lang.String, uri: str | java.lang.String, /) -> None: ...
    def unparsedEntityDecl(self, name: str | java.lang.String, publicId: str | java.lang.String, systemId: str | java.lang.String, notationName: str | java.lang.String, /) -> None: ...
    def warning(self, e: org.xml.sax.SAXParseException, /) -> None: ...

class LocatorImpl(org.xml.sax.Locator):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, locator: org.xml.sax.Locator, /) -> None: ...
    def getColumnNumber(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def getPublicId(self) -> str: ...
    def getSystemId(self) -> str: ...
    def setColumnNumber(self, columnNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLineNumber(self, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPublicId(self, publicId: str | java.lang.String, /) -> None: ...
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...

class NamespaceSupport(java.lang.Object):
    NSDECL: typing.ClassVar[str] = ...
    XMLNS: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def declarePrefix(self, prefix: str | java.lang.String, uri: str | java.lang.String, /) -> bool: ...
    def getDeclaredPrefixes(self) -> java.util.Enumeration: ...
    def getPrefix(self, uri: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getPrefixes(self) -> java.util.Enumeration: ...
    @typing.overload
    def getPrefixes(self, uri: str | java.lang.String, /) -> java.util.Enumeration: ...
    def getURI(self, prefix: str | java.lang.String, /) -> str: ...
    def isNamespaceDeclUris(self) -> bool: ...
    def popContext(self) -> None: ...
    def processName(self, qName: str | java.lang.String, parts: java.chaquopy.JavaArray[java.lang.String], isAttribute: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def pushContext(self) -> None: ...
    def reset(self) -> None: ...
    def setNamespaceDeclUris(self, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class ParserAdapter(org.xml.sax.DocumentHandler, org.xml.sax.XMLReader):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, parser: org.xml.sax.Parser, /) -> None: ...
    def characters(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def endDocument(self) -> None: ...
    def endElement(self, qName: str | java.lang.String, /) -> None: ...
    def getContentHandler(self) -> org.xml.sax.ContentHandler: ...
    def getDTDHandler(self) -> org.xml.sax.DTDHandler: ...
    def getEntityResolver(self) -> org.xml.sax.EntityResolver: ...
    def getErrorHandler(self) -> org.xml.sax.ErrorHandler: ...
    def getFeature(self, name: str | java.lang.String, /) -> bool: ...
    def getProperty(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def ignorableWhitespace(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def parse(self, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, input: org.xml.sax.InputSource, /) -> None: ...
    def processingInstruction(self, target: str | java.lang.String, data: str | java.lang.String, /) -> None: ...
    def setContentHandler(self, handler: org.xml.sax.ContentHandler, /) -> None: ...
    def setDTDHandler(self, handler: org.xml.sax.DTDHandler, /) -> None: ...
    def setDocumentLocator(self, locator: org.xml.sax.Locator, /) -> None: ...
    def setEntityResolver(self, resolver: org.xml.sax.EntityResolver, /) -> None: ...
    def setErrorHandler(self, handler: org.xml.sax.ErrorHandler, /) -> None: ...
    def setFeature(self, name: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProperty(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    def startDocument(self) -> None: ...
    def startElement(self, qName: str | java.lang.String, qAtts: org.xml.sax.AttributeList, /) -> None: ...

class ParserFactory(java.lang.Object):
    @typing.overload
    @staticmethod
    def makeParser() -> org.xml.sax.Parser: ...
    @typing.overload
    @staticmethod
    def makeParser(className: str | java.lang.String, /) -> org.xml.sax.Parser: ...

class XMLFilterImpl(org.xml.sax.ContentHandler, org.xml.sax.DTDHandler, org.xml.sax.EntityResolver, org.xml.sax.ErrorHandler, org.xml.sax.XMLFilter):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, parent: org.xml.sax.XMLReader, /) -> None: ...
    def characters(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def endDocument(self) -> None: ...
    def endElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, /) -> None: ...
    def endPrefixMapping(self, prefix: str | java.lang.String, /) -> None: ...
    def error(self, e: org.xml.sax.SAXParseException, /) -> None: ...
    def fatalError(self, e: org.xml.sax.SAXParseException, /) -> None: ...
    def getContentHandler(self) -> org.xml.sax.ContentHandler: ...
    def getDTDHandler(self) -> org.xml.sax.DTDHandler: ...
    def getEntityResolver(self) -> org.xml.sax.EntityResolver: ...
    def getErrorHandler(self) -> org.xml.sax.ErrorHandler: ...
    def getFeature(self, name: str | java.lang.String, /) -> bool: ...
    def getParent(self) -> org.xml.sax.XMLReader: ...
    def getProperty(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def ignorableWhitespace(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def notationDecl(self, name: str | java.lang.String, publicId: str | java.lang.String, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, input: org.xml.sax.InputSource, /) -> None: ...
    def processingInstruction(self, target: str | java.lang.String, data: str | java.lang.String, /) -> None: ...
    def resolveEntity(self, publicId: str | java.lang.String, systemId: str | java.lang.String, /) -> org.xml.sax.InputSource: ...
    def setContentHandler(self, handler: org.xml.sax.ContentHandler, /) -> None: ...
    def setDTDHandler(self, handler: org.xml.sax.DTDHandler, /) -> None: ...
    def setDocumentLocator(self, locator: org.xml.sax.Locator, /) -> None: ...
    def setEntityResolver(self, resolver: org.xml.sax.EntityResolver, /) -> None: ...
    def setErrorHandler(self, handler: org.xml.sax.ErrorHandler, /) -> None: ...
    def setFeature(self, name: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setParent(self, parent: org.xml.sax.XMLReader, /) -> None: ...
    def setProperty(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    def skippedEntity(self, name: str | java.lang.String, /) -> None: ...
    def startDocument(self) -> None: ...
    def startElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, atts: org.xml.sax.Attributes, /) -> None: ...
    def startPrefixMapping(self, prefix: str | java.lang.String, uri: str | java.lang.String, /) -> None: ...
    def unparsedEntityDecl(self, name: str | java.lang.String, publicId: str | java.lang.String, systemId: str | java.lang.String, notationName: str | java.lang.String, /) -> None: ...
    def warning(self, e: org.xml.sax.SAXParseException, /) -> None: ...

class XMLReaderAdapter(org.xml.sax.ContentHandler, org.xml.sax.Parser):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, xmlReader: org.xml.sax.XMLReader, /) -> None: ...
    def characters(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def endDocument(self) -> None: ...
    def endElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, /) -> None: ...
    def endPrefixMapping(self, prefix: str | java.lang.String, /) -> None: ...
    def ignorableWhitespace(self, ch: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def parse(self, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, input: org.xml.sax.InputSource, /) -> None: ...
    def processingInstruction(self, target: str | java.lang.String, data: str | java.lang.String, /) -> None: ...
    def setDTDHandler(self, handler: org.xml.sax.DTDHandler, /) -> None: ...
    def setDocumentHandler(self, handler: org.xml.sax.DocumentHandler, /) -> None: ...
    def setDocumentLocator(self, locator: org.xml.sax.Locator, /) -> None: ...
    def setEntityResolver(self, resolver: org.xml.sax.EntityResolver, /) -> None: ...
    def setErrorHandler(self, handler: org.xml.sax.ErrorHandler, /) -> None: ...
    def setLocale(self, locale: java.util.Locale, /) -> None: ...
    def skippedEntity(self, name: str | java.lang.String, /) -> None: ...
    def startDocument(self) -> None: ...
    def startElement(self, uri: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, atts: org.xml.sax.Attributes, /) -> None: ...
    def startPrefixMapping(self, prefix: str | java.lang.String, uri: str | java.lang.String, /) -> None: ...

class XMLReaderFactory(java.lang.Object):
    @typing.overload
    @staticmethod
    def createXMLReader() -> org.xml.sax.XMLReader: ...
    @typing.overload
    @staticmethod
    def createXMLReader(className: str | java.lang.String, /) -> org.xml.sax.XMLReader: ...



import typing

import android.app
import android.bluetooth
import android.content
import android.content.pm
import android.graphics
import android.hardware
import android.hardware.usb
import android.os
import android.util
import android.view
import android.view.accessibility
import android.view.inputmethod
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AccessibilityButtonController(java.lang.Object):
    def isAccessibilityButtonAvailable(self) -> bool: ...
    @typing.overload
    def registerAccessibilityButtonCallback(self, callback: AccessibilityButtonController.AccessibilityButtonCallback, /) -> None: ...
    @typing.overload
    def registerAccessibilityButtonCallback(self, callback: AccessibilityButtonController.AccessibilityButtonCallback, handler: android.os.Handler, /) -> None: ...
    def unregisterAccessibilityButtonCallback(self, callback: AccessibilityButtonController.AccessibilityButtonCallback, /) -> None: ...

    class AccessibilityButtonCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAvailabilityChanged(self, controller: AccessibilityButtonController, available: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onClicked(self, controller: AccessibilityButtonController, /) -> None: ...

class AccessibilityGestureEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityGestureEvent]] = ...
    def __init__(self, gestureId: int | java.jint | java.lang.Integer, displayId: int | java.jint | java.lang.Integer, motionEvents: java.util.List[android.view.MotionEvent], /) -> None: ...
    def describeContents(self) -> int: ...
    @staticmethod
    def gestureIdToString(id: int | java.jint | java.lang.Integer, /) -> str: ...
    def getDisplayId(self) -> int: ...
    def getGestureId(self) -> int: ...
    def getMotionEvents(self) -> java.util.List[android.view.MotionEvent]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AccessibilityService(android.app.Service):
    ERROR_TAKE_SCREENSHOT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    ERROR_TAKE_SCREENSHOT_INTERVAL_TIME_SHORT: typing.ClassVar[int] = ...
    ERROR_TAKE_SCREENSHOT_INVALID_DISPLAY: typing.ClassVar[int] = ...
    ERROR_TAKE_SCREENSHOT_INVALID_WINDOW: typing.ClassVar[int] = ...
    ERROR_TAKE_SCREENSHOT_NO_ACCESSIBILITY_ACCESS: typing.ClassVar[int] = ...
    ERROR_TAKE_SCREENSHOT_SECURE_WINDOW: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_DOUBLE_TAP: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_DOUBLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_SINGLE_TAP: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_SWIPE_DOWN: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_SWIPE_LEFT: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_SWIPE_RIGHT: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_SWIPE_UP: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_TRIPLE_TAP: typing.ClassVar[int] = ...
    GESTURE_2_FINGER_TRIPLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_DOUBLE_TAP: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_DOUBLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SINGLE_TAP: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SINGLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SWIPE_DOWN: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SWIPE_LEFT: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SWIPE_RIGHT: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_SWIPE_UP: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_TRIPLE_TAP: typing.ClassVar[int] = ...
    GESTURE_3_FINGER_TRIPLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_DOUBLE_TAP: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_DOUBLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_SINGLE_TAP: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_SWIPE_DOWN: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_SWIPE_LEFT: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_SWIPE_RIGHT: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_SWIPE_UP: typing.ClassVar[int] = ...
    GESTURE_4_FINGER_TRIPLE_TAP: typing.ClassVar[int] = ...
    GESTURE_DOUBLE_TAP: typing.ClassVar[int] = ...
    GESTURE_DOUBLE_TAP_AND_HOLD: typing.ClassVar[int] = ...
    GESTURE_SWIPE_DOWN: typing.ClassVar[int] = ...
    GESTURE_SWIPE_DOWN_AND_LEFT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_DOWN_AND_RIGHT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_DOWN_AND_UP: typing.ClassVar[int] = ...
    GESTURE_SWIPE_LEFT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_LEFT_AND_DOWN: typing.ClassVar[int] = ...
    GESTURE_SWIPE_LEFT_AND_RIGHT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_LEFT_AND_UP: typing.ClassVar[int] = ...
    GESTURE_SWIPE_RIGHT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_RIGHT_AND_DOWN: typing.ClassVar[int] = ...
    GESTURE_SWIPE_RIGHT_AND_LEFT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_RIGHT_AND_UP: typing.ClassVar[int] = ...
    GESTURE_SWIPE_UP: typing.ClassVar[int] = ...
    GESTURE_SWIPE_UP_AND_DOWN: typing.ClassVar[int] = ...
    GESTURE_SWIPE_UP_AND_LEFT: typing.ClassVar[int] = ...
    GESTURE_SWIPE_UP_AND_RIGHT: typing.ClassVar[int] = ...
    GESTURE_UNKNOWN: typing.ClassVar[int] = ...
    GLOBAL_ACTION_ACCESSIBILITY_ALL_APPS: typing.ClassVar[int] = ...
    GLOBAL_ACTION_ACCESSIBILITY_BUTTON: typing.ClassVar[int] = ...
    GLOBAL_ACTION_ACCESSIBILITY_BUTTON_CHOOSER: typing.ClassVar[int] = ...
    GLOBAL_ACTION_ACCESSIBILITY_SHORTCUT: typing.ClassVar[int] = ...
    GLOBAL_ACTION_BACK: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DISMISS_NOTIFICATION_SHADE: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DPAD_CENTER: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DPAD_DOWN: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DPAD_LEFT: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DPAD_RIGHT: typing.ClassVar[int] = ...
    GLOBAL_ACTION_DPAD_UP: typing.ClassVar[int] = ...
    GLOBAL_ACTION_HOME: typing.ClassVar[int] = ...
    GLOBAL_ACTION_KEYCODE_HEADSETHOOK: typing.ClassVar[int] = ...
    GLOBAL_ACTION_LOCK_SCREEN: typing.ClassVar[int] = ...
    GLOBAL_ACTION_MEDIA_PLAY_PAUSE: typing.ClassVar[int] = ...
    GLOBAL_ACTION_MENU: typing.ClassVar[int] = ...
    GLOBAL_ACTION_NOTIFICATIONS: typing.ClassVar[int] = ...
    GLOBAL_ACTION_POWER_DIALOG: typing.ClassVar[int] = ...
    GLOBAL_ACTION_QUICK_SETTINGS: typing.ClassVar[int] = ...
    GLOBAL_ACTION_RECENTS: typing.ClassVar[int] = ...
    GLOBAL_ACTION_TAKE_SCREENSHOT: typing.ClassVar[int] = ...
    GLOBAL_ACTION_TOGGLE_SPLIT_SCREEN: typing.ClassVar[int] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    SHOW_MODE_AUTO: typing.ClassVar[int] = ...
    SHOW_MODE_HIDDEN: typing.ClassVar[int] = ...
    SHOW_MODE_IGNORE_HARD_KEYBOARD: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def attachAccessibilityOverlayToDisplay(self, displayId: int | java.jint | java.lang.Integer, sc: android.view.SurfaceControl, /) -> None: ...
    def attachAccessibilityOverlayToWindow(self, accessibilityWindowId: int | java.jint | java.lang.Integer, sc: android.view.SurfaceControl, /) -> None: ...
    def clearCache(self) -> bool: ...
    def clearCachedSubtree(self, node: android.view.accessibility.AccessibilityNodeInfo, /) -> bool: ...
    def createDisplayContext(self, display: android.view.Display, /) -> android.content.Context: ...
    @typing.overload
    def createWindowContext(self, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> android.content.Context | None: ...
    @typing.overload
    def createWindowContext(self, display: android.view.Display, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> android.content.Context | None: ...
    def disableSelf(self) -> None: ...
    def dispatchGesture(self, gesture: GestureDescription, callback: AccessibilityService.GestureResultCallback, handler: android.os.Handler, /) -> bool: ...
    def findFocus(self, focus: int | java.jint | java.lang.Integer, /) -> android.view.accessibility.AccessibilityNodeInfo | None: ...
    @typing.overload
    def getAccessibilityButtonController(self) -> AccessibilityButtonController: ...
    @typing.overload
    def getAccessibilityButtonController(self, displayId: int | java.jint | java.lang.Integer, /) -> AccessibilityButtonController: ...
    def getBrailleDisplayController(self) -> BrailleDisplayController: ...
    def getFingerprintGestureController(self) -> FingerprintGestureController: ...
    def getInputMethod(self) -> InputMethod | None: ...
    def getMagnificationController(self) -> AccessibilityService.MagnificationController: ...
    @typing.overload
    def getRootInActiveWindow(self) -> android.view.accessibility.AccessibilityNodeInfo | None: ...
    @typing.overload
    def getRootInActiveWindow(self, prefetchingStrategy: int | java.jint | java.lang.Integer, /) -> android.view.accessibility.AccessibilityNodeInfo | None: ...
    def getServiceInfo(self) -> AccessibilityServiceInfo: ...
    def getSoftKeyboardController(self) -> AccessibilityService.SoftKeyboardController: ...
    def getSystemActions(self) -> java.util.List[android.view.accessibility.AccessibilityNodeInfo.AccessibilityAction]: ...
    def getSystemService(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getTouchInteractionController(self, displayId: int | java.jint | java.lang.Integer, /) -> TouchInteractionController: ...
    def getWindows(self) -> java.util.List[android.view.accessibility.AccessibilityWindowInfo]: ...
    def getWindowsOnAllDisplays(self) -> android.util.SparseArray[java.util.List[android.view.accessibility.AccessibilityWindowInfo]]: ...
    def isCacheEnabled(self) -> bool: ...
    def isNodeInCache(self, node: android.view.accessibility.AccessibilityNodeInfo, /) -> bool: ...
    def onAccessibilityEvent(self, arg1: android.view.accessibility.AccessibilityEvent, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCreateInputMethod(self) -> InputMethod: ...
    @typing.overload
    def onGesture(self, gestureId: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def onGesture(self, gestureEvent: AccessibilityGestureEvent, /) -> bool: ...
    def onInterrupt(self) -> None: ...
    def onKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def onMotionEvent(self, event: android.view.MotionEvent, /) -> None: ...
    def onServiceConnected(self) -> None: ...
    def onSystemActionsChanged(self) -> None: ...
    def performGlobalAction(self, action: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setAccessibilityFocusAppearance(self, strokeWidth: int | java.jint | java.lang.Integer, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAnimationScale(self, scale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setGestureDetectionPassthroughRegion(self, displayId: int | java.jint | java.lang.Integer, region: android.graphics.Region, /) -> None: ...
    def setServiceInfo(self, info: AccessibilityServiceInfo, /) -> None: ...
    def setTouchExplorationPassthroughRegion(self, displayId: int | java.jint | java.lang.Integer, region: android.graphics.Region, /) -> None: ...
    def takeScreenshot(self, displayId: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: AccessibilityService.TakeScreenshotCallback, /) -> None: ...
    def takeScreenshotOfWindow(self, accessibilityWindowId: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: AccessibilityService.TakeScreenshotCallback, /) -> None: ...

    class TakeScreenshotCallback(java.lang.Object):
        def onFailure(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSuccess(self, arg1: AccessibilityService.ScreenshotResult, /) -> None: ...

    class SoftKeyboardController(java.lang.Object):
        ENABLE_IME_FAIL_BY_ADMIN: typing.ClassVar[int] = ...
        ENABLE_IME_FAIL_UNKNOWN: typing.ClassVar[int] = ...
        ENABLE_IME_SUCCESS: typing.ClassVar[int] = ...
        @typing.overload
        def addOnShowModeChangedListener(self, listener: AccessibilityService.SoftKeyboardController.OnShowModeChangedListener, /) -> None: ...
        @typing.overload
        def addOnShowModeChangedListener(self, listener: AccessibilityService.SoftKeyboardController.OnShowModeChangedListener, handler: android.os.Handler, /) -> None: ...
        def getShowMode(self) -> int: ...
        def removeOnShowModeChangedListener(self, listener: AccessibilityService.SoftKeyboardController.OnShowModeChangedListener, /) -> bool: ...
        def setInputMethodEnabled(self, imeId: str | java.lang.String, enabled: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
        def setShowMode(self, showMode: int | java.jint | java.lang.Integer, /) -> bool: ...
        def switchToInputMethod(self, imeId: str | java.lang.String, /) -> bool: ...

        class OnShowModeChangedListener(java.lang.Object):
            def onShowModeChanged(self, arg1: AccessibilityService.SoftKeyboardController, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class ScreenshotResult(java.lang.Object):
        def getColorSpace(self) -> android.graphics.ColorSpace: ...
        def getHardwareBuffer(self) -> android.hardware.HardwareBuffer: ...
        def getTimestamp(self) -> int: ...

    class MagnificationController(java.lang.Object):
        @typing.overload
        def addListener(self, listener: AccessibilityService.MagnificationController.OnMagnificationChangedListener, /) -> None: ...
        @typing.overload
        def addListener(self, listener: AccessibilityService.MagnificationController.OnMagnificationChangedListener, handler: android.os.Handler, /) -> None: ...
        def getCenterX(self) -> float: ...
        def getCenterY(self) -> float: ...
        def getCurrentMagnificationRegion(self) -> android.graphics.Region: ...
        def getMagnificationConfig(self) -> MagnificationConfig: ...
        def getMagnificationRegion(self) -> android.graphics.Region: ...
        def getScale(self) -> float: ...
        def removeListener(self, listener: AccessibilityService.MagnificationController.OnMagnificationChangedListener, /) -> bool: ...
        def reset(self, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def resetCurrentMagnification(self, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def setCenter(self, centerX: float | java.jfloat | java.lang.Float, centerY: float | java.jfloat | java.lang.Float, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def setMagnificationConfig(self, config: MagnificationConfig, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def setScale(self, scale: float | java.jfloat | java.lang.Float, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...

        class OnMagnificationChangedListener(java.lang.Object):
            @typing.overload
            def onMagnificationChanged(self, controller: AccessibilityService.MagnificationController, region: android.graphics.Region, config: MagnificationConfig, /) -> None: ...
            @typing.overload
            def onMagnificationChanged(self, arg1: AccessibilityService.MagnificationController, arg2: android.graphics.Region, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...

    class GestureResultCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onCancelled(self, gestureDescription: GestureDescription, /) -> None: ...
        def onCompleted(self, gestureDescription: GestureDescription, /) -> None: ...

class AccessibilityServiceInfo(android.os.Parcelable):
    CAPABILITY_CAN_CONTROL_MAGNIFICATION: typing.ClassVar[int] = ...
    CAPABILITY_CAN_PERFORM_GESTURES: typing.ClassVar[int] = ...
    CAPABILITY_CAN_REQUEST_ENHANCED_WEB_ACCESSIBILITY: typing.ClassVar[int] = ...
    CAPABILITY_CAN_REQUEST_FILTER_KEY_EVENTS: typing.ClassVar[int] = ...
    CAPABILITY_CAN_REQUEST_FINGERPRINT_GESTURES: typing.ClassVar[int] = ...
    CAPABILITY_CAN_REQUEST_TOUCH_EXPLORATION: typing.ClassVar[int] = ...
    CAPABILITY_CAN_RETRIEVE_WINDOW_CONTENT: typing.ClassVar[int] = ...
    CAPABILITY_CAN_TAKE_SCREENSHOT: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityServiceInfo]] = ...
    DEFAULT: typing.ClassVar[int] = ...
    FEEDBACK_ALL_MASK: typing.ClassVar[int] = ...
    FEEDBACK_AUDIBLE: typing.ClassVar[int] = ...
    FEEDBACK_BRAILLE: typing.ClassVar[int] = ...
    FEEDBACK_GENERIC: typing.ClassVar[int] = ...
    FEEDBACK_HAPTIC: typing.ClassVar[int] = ...
    FEEDBACK_SPOKEN: typing.ClassVar[int] = ...
    FEEDBACK_VISUAL: typing.ClassVar[int] = ...
    FLAG_ENABLE_ACCESSIBILITY_VOLUME: typing.ClassVar[int] = ...
    FLAG_INCLUDE_NOT_IMPORTANT_VIEWS: typing.ClassVar[int] = ...
    FLAG_INPUT_METHOD_EDITOR: typing.ClassVar[int] = ...
    FLAG_REPORT_VIEW_IDS: typing.ClassVar[int] = ...
    FLAG_REQUEST_2_FINGER_PASSTHROUGH: typing.ClassVar[int] = ...
    FLAG_REQUEST_ACCESSIBILITY_BUTTON: typing.ClassVar[int] = ...
    FLAG_REQUEST_ENHANCED_WEB_ACCESSIBILITY: typing.ClassVar[int] = ...
    FLAG_REQUEST_FILTER_KEY_EVENTS: typing.ClassVar[int] = ...
    FLAG_REQUEST_FINGERPRINT_GESTURES: typing.ClassVar[int] = ...
    FLAG_REQUEST_MULTI_FINGER_GESTURES: typing.ClassVar[int] = ...
    FLAG_REQUEST_SHORTCUT_WARNING_DIALOG_SPOKEN_FEEDBACK: typing.ClassVar[int] = ...
    FLAG_REQUEST_TOUCH_EXPLORATION_MODE: typing.ClassVar[int] = ...
    FLAG_RETRIEVE_INTERACTIVE_WINDOWS: typing.ClassVar[int] = ...
    FLAG_SEND_MOTION_EVENTS: typing.ClassVar[int] = ...
    FLAG_SERVICE_HANDLES_DOUBLE_TAP: typing.ClassVar[int] = ...
    eventTypes: int = ...
    feedbackType: int = ...
    flags: int = ...
    notificationTimeout: int = ...
    packageNames: java.chaquopy.JavaArray[java.lang.String] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def capabilityToString(capability: int | java.jint | java.lang.Integer, /) -> str: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def feedbackTypeToString(feedbackType: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def flagToString(flag: int | java.jint | java.lang.Integer, /) -> str: ...
    def getCanRetrieveWindowContent(self) -> bool: ...
    def getCapabilities(self) -> int: ...
    def getDescription(self) -> str: ...
    def getId(self) -> str: ...
    def getInteractiveUiTimeoutMillis(self) -> int: ...
    def getMotionEventSources(self) -> int: ...
    def getNonInteractiveUiTimeoutMillis(self) -> int: ...
    def getResolveInfo(self) -> android.content.pm.ResolveInfo: ...
    def getSettingsActivityName(self) -> str: ...
    def getTileServiceName(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def isAccessibilityTool(self) -> bool: ...
    def loadDescription(self, packageManager: android.content.pm.PackageManager, /) -> str: ...
    def loadIntro(self, packageManager: android.content.pm.PackageManager, /) -> java.lang.CharSequence | None: ...
    def loadSummary(self, packageManager: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def setInteractiveUiTimeoutMillis(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMotionEventSources(self, motionEventSources: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNonInteractiveUiTimeoutMillis(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flagz: int | java.jint | java.lang.Integer, /) -> None: ...

class BrailleDisplayController(java.lang.Object):
    @typing.overload
    def connect(self, arg1: android.bluetooth.BluetoothDevice, arg2: BrailleDisplayController.BrailleDisplayCallback, /) -> None: ...
    @typing.overload
    def connect(self, arg1: android.hardware.usb.UsbDevice, arg2: BrailleDisplayController.BrailleDisplayCallback, /) -> None: ...
    @typing.overload
    def connect(self, arg1: android.bluetooth.BluetoothDevice, arg2: java.util.concurrent.Executor, arg3: BrailleDisplayController.BrailleDisplayCallback, /) -> None: ...
    @typing.overload
    def connect(self, arg1: android.hardware.usb.UsbDevice, arg2: java.util.concurrent.Executor, arg3: BrailleDisplayController.BrailleDisplayCallback, /) -> None: ...
    def disconnect(self) -> None: ...
    def isConnected(self) -> bool: ...
    def write(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...

    class BrailleDisplayCallback(java.lang.Object):
        FLAG_ERROR_BRAILLE_DISPLAY_NOT_FOUND: typing.ClassVar[int] = ...
        FLAG_ERROR_CANNOT_ACCESS: typing.ClassVar[int] = ...
        def onConnected(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onConnectionFailed(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onDisconnected(self) -> None: ...
        def onInput(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...

class FingerprintGestureController(java.lang.Object):
    FINGERPRINT_GESTURE_SWIPE_DOWN: typing.ClassVar[int] = ...
    FINGERPRINT_GESTURE_SWIPE_LEFT: typing.ClassVar[int] = ...
    FINGERPRINT_GESTURE_SWIPE_RIGHT: typing.ClassVar[int] = ...
    FINGERPRINT_GESTURE_SWIPE_UP: typing.ClassVar[int] = ...
    def isGestureDetectionAvailable(self) -> bool: ...
    def registerFingerprintGestureCallback(self, callback: FingerprintGestureController.FingerprintGestureCallback, handler: android.os.Handler, /) -> None: ...
    def unregisterFingerprintGestureCallback(self, callback: FingerprintGestureController.FingerprintGestureCallback, /) -> None: ...

    class FingerprintGestureCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onGestureDetected(self, gesture: int | java.jint | java.lang.Integer, /) -> None: ...
        def onGestureDetectionAvailabilityChanged(self, available: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class GestureDescription(java.lang.Object):
    def getDisplayId(self) -> int: ...
    @staticmethod
    def getMaxGestureDuration() -> int: ...
    @staticmethod
    def getMaxStrokeCount() -> int: ...
    def getStroke(self, index: int | java.jint | java.lang.Integer, /) -> GestureDescription.StrokeDescription: ...
    def getStrokeCount(self) -> int: ...

    class StrokeDescription(java.lang.Object):
        @typing.overload
        def __init__(self, path: android.graphics.Path, startTime: int | java.jlong | java.lang.Long, duration: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def __init__(self, path: android.graphics.Path, startTime: int | java.jlong | java.lang.Long, duration: int | java.jlong | java.lang.Long, willContinue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def continueStroke(self, path: android.graphics.Path, startTime: int | java.jlong | java.lang.Long, duration: int | java.jlong | java.lang.Long, willContinue: bool | java.jboolean | java.lang.Boolean, /) -> GestureDescription.StrokeDescription: ...
        def getDuration(self) -> int: ...
        def getPath(self) -> android.graphics.Path: ...
        def getStartTime(self) -> int: ...
        def willContinue(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addStroke(self, strokeDescription: GestureDescription.StrokeDescription, /) -> GestureDescription.Builder: ...
        def build(self) -> GestureDescription: ...
        def setDisplayId(self, displayId: int | java.jint | java.lang.Integer, /) -> GestureDescription.Builder: ...

class InputMethod(java.lang.Object):
    def __init__(self, service: AccessibilityService, /) -> None: ...
    def getCurrentInputConnection(self) -> InputMethod.AccessibilityInputConnection | None: ...
    def getCurrentInputEditorInfo(self) -> android.view.inputmethod.EditorInfo | None: ...
    def getCurrentInputStarted(self) -> bool: ...
    def onFinishInput(self) -> None: ...
    def onStartInput(self, attribute: android.view.inputmethod.EditorInfo, restarting: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onUpdateSelection(self, oldSelStart: int | java.jint | java.lang.Integer, oldSelEnd: int | java.jint | java.lang.Integer, newSelStart: int | java.jint | java.lang.Integer, newSelEnd: int | java.jint | java.lang.Integer, candidatesStart: int | java.jint | java.lang.Integer, candidatesEnd: int | java.jint | java.lang.Integer, /) -> None: ...

    class AccessibilityInputConnection(java.lang.Object):
        def clearMetaKeyStates(self, states: int | java.jint | java.lang.Integer, /) -> None: ...
        def commitText(self, text: java.lang.CharSequence, newCursorPosition: int | java.jint | java.lang.Integer, textAttribute: android.view.inputmethod.TextAttribute, /) -> None: ...
        def deleteSurroundingText(self, beforeLength: int | java.jint | java.lang.Integer, afterLength: int | java.jint | java.lang.Integer, /) -> None: ...
        def getCursorCapsMode(self, reqModes: int | java.jint | java.lang.Integer, /) -> int: ...
        def getSurroundingText(self, beforeLength: int | java.jint | java.lang.Integer, afterLength: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> android.view.inputmethod.SurroundingText: ...
        def performContextMenuAction(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
        def performEditorAction(self, editorAction: int | java.jint | java.lang.Integer, /) -> None: ...
        def sendKeyEvent(self, event: android.view.KeyEvent, /) -> None: ...
        def setSelection(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...

class MagnificationConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MagnificationConfig]] = ...
    MAGNIFICATION_MODE_DEFAULT: typing.ClassVar[int] = ...
    MAGNIFICATION_MODE_FULLSCREEN: typing.ClassVar[int] = ...
    MAGNIFICATION_MODE_WINDOW: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getCenterX(self) -> float: ...
    def getCenterY(self) -> float: ...
    def getMode(self) -> int: ...
    def getScale(self) -> float: ...
    def isActivated(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> MagnificationConfig: ...
        def setActivated(self, activated: bool | java.jboolean | java.lang.Boolean, /) -> MagnificationConfig.Builder: ...
        def setCenterX(self, centerX: float | java.jfloat | java.lang.Float, /) -> MagnificationConfig.Builder: ...
        def setCenterY(self, centerY: float | java.jfloat | java.lang.Float, /) -> MagnificationConfig.Builder: ...
        def setMode(self, mode: int | java.jint | java.lang.Integer, /) -> MagnificationConfig.Builder: ...
        def setScale(self, scale: float | java.jfloat | java.lang.Float, /) -> MagnificationConfig.Builder: ...

class TouchInteractionController(java.lang.Object):
    STATE_CLEAR: typing.ClassVar[int] = ...
    STATE_DELEGATING: typing.ClassVar[int] = ...
    STATE_DRAGGING: typing.ClassVar[int] = ...
    STATE_TOUCH_EXPLORING: typing.ClassVar[int] = ...
    STATE_TOUCH_INTERACTING: typing.ClassVar[int] = ...
    def getDisplayId(self) -> int: ...
    def getMaxPointerCount(self) -> int: ...
    def getState(self) -> int: ...
    def performClick(self) -> None: ...
    def performLongClickAndStartDrag(self) -> None: ...
    def registerCallback(self, executor: java.util.concurrent.Executor, callback: TouchInteractionController.Callback, /) -> None: ...
    def requestDelegating(self) -> None: ...
    def requestDragging(self, pointerId: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestTouchExploration(self) -> None: ...
    @staticmethod
    def stateToString(state: int | java.jint | java.lang.Integer, /) -> str: ...
    def unregisterAllCallbacks(self) -> None: ...
    def unregisterCallback(self, callback: TouchInteractionController.Callback, /) -> bool: ...

    class Callback(java.lang.Object):
        def onMotionEvent(self, arg1: android.view.MotionEvent, /) -> None: ...
        def onStateChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.nio
import java.util

class ApplicationRuntime(java.lang.Object):
    @staticmethod
    def getBaseApkOptimizationInfo() -> DexFile.OptimizationInfo: ...

class BaseDexClassLoader(java.lang.ClassLoader):
    def __init__(self, dexPath: str | java.lang.String, optimizedDirectory: java.io.File, librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...
    def findClass(self, name: str | java.lang.String, /) -> typing.Type[java.lang.Object]: ...
    def findLibrary(self, name: str | java.lang.String, /) -> str: ...
    def findResource(self, name: str | java.lang.String, /) -> java.net.URL: ...
    def findResources(self, name: str | java.lang.String, /) -> java.util.Enumeration[java.net.URL]: ...
    def getPackage(self, name: str | java.lang.String, /) -> java.lang.Package: ...
    def toString(self) -> str: ...

class DelegateLastClassLoader(PathClassLoader):
    @typing.overload
    def __init__(self, dexPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...
    @typing.overload
    def __init__(self, dexPath: str | java.lang.String, librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...
    @typing.overload
    def __init__(self, dexPath: str | java.lang.String, librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, delegateResourceLoading: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getResource(self, name: str | java.lang.String, /) -> java.net.URL: ...
    def getResources(self, name: str | java.lang.String, /) -> java.util.Enumeration[java.net.URL]: ...
    def loadClass(self, name: str | java.lang.String, resolve: bool | java.jboolean | java.lang.Boolean, /) -> typing.Type[java.lang.Object]: ...

class DexClassLoader(BaseDexClassLoader):
    def __init__(self, dexPath: str | java.lang.String, optimizedDirectory: str | java.lang.String, librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...

class DexFile(java.lang.Object):
    @typing.overload
    def __init__(self, file: java.io.File, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def entries(self) -> java.util.Enumeration[java.lang.String]: ...
    def finalize(self) -> None: ...
    def getName(self) -> str: ...
    @staticmethod
    def isDexOptNeeded(arg1: str | java.lang.String, /) -> bool: ...
    def loadClass(self, name: str | java.lang.String, loader: java.lang.ClassLoader, /) -> typing.Type: ...
    @staticmethod
    def loadDex(sourcePathName: str | java.lang.String, outputPathName: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> DexFile: ...
    def toString(self) -> str: ...

    class OptimizationInfo(java.lang.Object):
        def isFullyCompiled(self) -> bool: ...
        def isOptimized(self) -> bool: ...
        def isVerified(self) -> bool: ...

class InMemoryDexClassLoader(BaseDexClassLoader):
    @typing.overload
    def __init__(self, dexBuffer: java.nio.ByteBuffer, parent: java.lang.ClassLoader, /) -> None: ...
    @typing.overload
    def __init__(self, dexBuffers: java.chaquopy.JavaArray[java.nio.ByteBuffer], parent: java.lang.ClassLoader, /) -> None: ...
    @typing.overload
    def __init__(self, dexBuffers: java.chaquopy.JavaArray[java.nio.ByteBuffer], librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...

class PathClassLoader(BaseDexClassLoader):
    @typing.overload
    def __init__(self, dexPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...
    @typing.overload
    def __init__(self, dexPath: str | java.lang.String, librarySearchPath: str | java.lang.String, parent: java.lang.ClassLoader, /) -> None: ...

class ZipPathValidator(java.lang.Object):
    @staticmethod
    def clearCallback() -> None: ...
    @staticmethod
    def setCallback(callback: ZipPathValidator.Callback, /) -> None: ...

    class Callback(java.lang.Object):
        def onZipEntryAccess(self, path: str | java.lang.String, /) -> None: ...



import typing

import android.app.appsearch
import java.lang

class DocumentIdUtil(java.lang.Object):
    @typing.overload
    @staticmethod
    def createQualifiedId(packageName: str | java.lang.String, databaseName: str | java.lang.String, document: android.app.appsearch.GenericDocument, /) -> str: ...
    @typing.overload
    @staticmethod
    def createQualifiedId(packageName: str | java.lang.String, databaseName: str | java.lang.String, namespace: str | java.lang.String, id: str | java.lang.String, /) -> str: ...



import typing

import android.health.connect.datatypes
import android.os
import java
import java.lang
import java.time
import java.util

class ChangeLogTokenRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChangeLogTokenRequest]] = ...
    def describeContents(self) -> int: ...
    def getDataOriginFilters(self) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getRecordTypes(self) -> java.util.Set[typing.Type[android.health.connect.datatypes.Record]]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDataOriginFilter(self, dataOriginFilter: android.health.connect.datatypes.DataOrigin, /) -> ChangeLogTokenRequest.Builder: ...
        def addRecordType(self, recordType: typing.Type[android.health.connect.datatypes.Record], /) -> ChangeLogTokenRequest.Builder: ...
        def build(self) -> ChangeLogTokenRequest: ...

class ChangeLogTokenResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChangeLogTokenResponse]] = ...
    def describeContents(self) -> int: ...
    def getToken(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ChangeLogsRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChangeLogsRequest]] = ...
    def describeContents(self) -> int: ...
    def getPageSize(self) -> int: ...
    def getToken(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, token: str | java.lang.String, /) -> None: ...
        def build(self) -> ChangeLogsRequest: ...
        def setPageSize(self, pageSize: int | java.jint | java.lang.Integer, /) -> ChangeLogsRequest.Builder: ...

class ChangeLogsResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChangeLogsResponse]] = ...
    def describeContents(self) -> int: ...
    def getDeletedLogs(self) -> java.util.List[ChangeLogsResponse.DeletedLog]: ...
    def getNextChangesToken(self) -> str: ...
    def getUpsertedRecords(self) -> java.util.List[android.health.connect.datatypes.Record]: ...
    def hasMorePages(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class DeletedLog(java.lang.Object):
        def __init__(self, deletedRecordId: str | java.lang.String, deletedTime: int | java.jlong | java.lang.Long, /) -> None: ...
        def getDeletedRecordId(self) -> str: ...
        def getDeletedTime(self) -> java.time.Instant: ...



import java
import java.lang
import java.net
import org.apache.http.params

class HostNameResolver(java.lang.Object):
    def resolve(self, arg1: str | java.lang.String, /) -> java.net.InetAddress: ...

class LayeredSocketFactory(SocketFactory):
    def createSocket(self, arg1: java.net.Socket, arg2: str | java.lang.String, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, /) -> java.net.Socket: ...

class SocketFactory(java.lang.Object):
    def connectSocket(self, arg1: java.net.Socket, arg2: str | java.lang.String, arg3: int | java.jint | java.lang.Integer, arg4: java.net.InetAddress, arg5: int | java.jint | java.lang.Integer, arg6: org.apache.http.params.HttpParams, /) -> java.net.Socket: ...
    def createSocket(self) -> java.net.Socket: ...
    def isSecure(self, arg1: java.net.Socket, /) -> bool: ...



import typing

import java
import java.lang
import java.util

_BiConsumer__T = typing.TypeVar('_BiConsumer__T')  # <T>
_BiConsumer__U = typing.TypeVar('_BiConsumer__U')  # <U>
class BiConsumer(java.lang.Object, typing.Generic[_BiConsumer__T, _BiConsumer__U]):
    def accept(self, arg1: _BiConsumer__T, arg2: _BiConsumer__U, /) -> None: ...
    def andThen(self, after: BiConsumer[_BiConsumer__T, _BiConsumer__U], /) -> BiConsumer[_BiConsumer__T, _BiConsumer__U]: ...

_BiFunction__T = typing.TypeVar('_BiFunction__T')  # <T>
_BiFunction__U = typing.TypeVar('_BiFunction__U')  # <U>
_BiFunction__R = typing.TypeVar('_BiFunction__R')  # <R>
class BiFunction(java.lang.Object, typing.Generic[_BiFunction__T, _BiFunction__U, _BiFunction__R]):
    _andThen__V = typing.TypeVar('_andThen__V')  # <V>
    def andThen(self, after: Function[_BiFunction__R, _andThen__V], /) -> BiFunction[_BiFunction__T, _BiFunction__U, _andThen__V]: ...
    def apply(self, arg1: _BiFunction__T, arg2: _BiFunction__U, /) -> _BiFunction__R: ...

_BiPredicate__T = typing.TypeVar('_BiPredicate__T')  # <T>
_BiPredicate__U = typing.TypeVar('_BiPredicate__U')  # <U>
class BiPredicate(java.lang.Object, typing.Generic[_BiPredicate__T, _BiPredicate__U]):
    def and_(self, other: BiPredicate[_BiPredicate__T, _BiPredicate__U], /) -> BiPredicate[_BiPredicate__T, _BiPredicate__U]: ...
    def negate(self) -> BiPredicate[_BiPredicate__T, _BiPredicate__U]: ...
    def or_(self, other: BiPredicate[_BiPredicate__T, _BiPredicate__U], /) -> BiPredicate[_BiPredicate__T, _BiPredicate__U]: ...
    def test(self, arg1: _BiPredicate__T, arg2: _BiPredicate__U, /) -> bool: ...

_BinaryOperator__T = typing.TypeVar('_BinaryOperator__T')  # <T>
class BinaryOperator(BiFunction[_BinaryOperator__T, _BinaryOperator__T, _BinaryOperator__T], typing.Generic[_BinaryOperator__T]):
    _maxBy__T = typing.TypeVar('_maxBy__T')  # <T>
    @staticmethod
    def maxBy(comparator: java.util.Comparator[_maxBy__T], /) -> BinaryOperator[_maxBy__T]: ...
    _minBy__T = typing.TypeVar('_minBy__T')  # <T>
    @staticmethod
    def minBy(comparator: java.util.Comparator[_minBy__T], /) -> BinaryOperator[_minBy__T]: ...

class BooleanSupplier(java.lang.Object):
    def getAsBoolean(self) -> bool: ...

_Consumer__T = typing.TypeVar('_Consumer__T')  # <T>
class Consumer(java.lang.Object, typing.Generic[_Consumer__T]):
    def accept(self, arg1: _Consumer__T, /) -> None: ...
    def andThen(self, after: Consumer[_Consumer__T], /) -> Consumer[_Consumer__T]: ...

class DoubleBinaryOperator(java.lang.Object):
    def applyAsDouble(self, arg1: float | java.jdouble | java.lang.Double, arg2: float | java.jdouble | java.lang.Double, /) -> float: ...

class DoubleConsumer(java.lang.Object):
    def accept(self, arg1: float | java.jdouble | java.lang.Double, /) -> None: ...
    def andThen(self, after: DoubleConsumer, /) -> DoubleConsumer: ...

_DoubleFunction__R = typing.TypeVar('_DoubleFunction__R')  # <R>
class DoubleFunction(java.lang.Object, typing.Generic[_DoubleFunction__R]):
    def apply(self, arg1: float | java.jdouble | java.lang.Double, /) -> _DoubleFunction__R: ...

class DoublePredicate(java.lang.Object):
    def and_(self, other: DoublePredicate, /) -> DoublePredicate: ...
    def negate(self) -> DoublePredicate: ...
    def or_(self, other: DoublePredicate, /) -> DoublePredicate: ...
    def test(self, arg1: float | java.jdouble | java.lang.Double, /) -> bool: ...

class DoubleSupplier(java.lang.Object):
    def getAsDouble(self) -> float: ...

class DoubleToIntFunction(java.lang.Object):
    def applyAsInt(self, arg1: float | java.jdouble | java.lang.Double, /) -> int: ...

class DoubleToLongFunction(java.lang.Object):
    def applyAsLong(self, arg1: float | java.jdouble | java.lang.Double, /) -> int: ...

class DoubleUnaryOperator(java.lang.Object):
    def andThen(self, after: DoubleUnaryOperator, /) -> DoubleUnaryOperator: ...
    def applyAsDouble(self, arg1: float | java.jdouble | java.lang.Double, /) -> float: ...
    def compose(self, before: DoubleUnaryOperator, /) -> DoubleUnaryOperator: ...
    @staticmethod
    def identity() -> DoubleUnaryOperator: ...

_Function__T = typing.TypeVar('_Function__T')  # <T>
_Function__R = typing.TypeVar('_Function__R')  # <R>
class Function(java.lang.Object, typing.Generic[_Function__T, _Function__R]):
    _andThen__V = typing.TypeVar('_andThen__V')  # <V>
    def andThen(self, after: Function[_Function__R, _andThen__V], /) -> Function[_Function__T, _andThen__V]: ...
    def apply(self, arg1: _Function__T, /) -> _Function__R: ...
    _compose__V = typing.TypeVar('_compose__V')  # <V>
    def compose(self, before: Function[_compose__V, _Function__T], /) -> Function[_compose__V, _Function__R]: ...
    _identity__T = typing.TypeVar('_identity__T')  # <T>
    @staticmethod
    def identity() -> Function[_identity__T, _identity__T]: ...

class IntBinaryOperator(java.lang.Object):
    def applyAsInt(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> int: ...

class IntConsumer(java.lang.Object):
    def accept(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def andThen(self, after: IntConsumer, /) -> IntConsumer: ...

_IntFunction__R = typing.TypeVar('_IntFunction__R')  # <R>
class IntFunction(java.lang.Object, typing.Generic[_IntFunction__R]):
    def apply(self, arg1: int | java.jint | java.lang.Integer, /) -> _IntFunction__R: ...

class IntPredicate(java.lang.Object):
    def and_(self, other: IntPredicate, /) -> IntPredicate: ...
    def negate(self) -> IntPredicate: ...
    def or_(self, other: IntPredicate, /) -> IntPredicate: ...
    def test(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...

class IntSupplier(java.lang.Object):
    def getAsInt(self) -> int: ...

class IntToDoubleFunction(java.lang.Object):
    def applyAsDouble(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...

class IntToLongFunction(java.lang.Object):
    def applyAsLong(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...

class IntUnaryOperator(java.lang.Object):
    def andThen(self, after: IntUnaryOperator, /) -> IntUnaryOperator: ...
    def applyAsInt(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def compose(self, before: IntUnaryOperator, /) -> IntUnaryOperator: ...
    @staticmethod
    def identity() -> IntUnaryOperator: ...

class LongBinaryOperator(java.lang.Object):
    def applyAsLong(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, /) -> int: ...

class LongConsumer(java.lang.Object):
    def accept(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...
    def andThen(self, after: LongConsumer, /) -> LongConsumer: ...

_LongFunction__R = typing.TypeVar('_LongFunction__R')  # <R>
class LongFunction(java.lang.Object, typing.Generic[_LongFunction__R]):
    def apply(self, arg1: int | java.jlong | java.lang.Long, /) -> _LongFunction__R: ...

class LongPredicate(java.lang.Object):
    def and_(self, other: LongPredicate, /) -> LongPredicate: ...
    def negate(self) -> LongPredicate: ...
    def or_(self, other: LongPredicate, /) -> LongPredicate: ...
    def test(self, arg1: int | java.jlong | java.lang.Long, /) -> bool: ...

class LongSupplier(java.lang.Object):
    def getAsLong(self) -> int: ...

class LongToDoubleFunction(java.lang.Object):
    def applyAsDouble(self, arg1: int | java.jlong | java.lang.Long, /) -> float: ...

class LongToIntFunction(java.lang.Object):
    def applyAsInt(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...

class LongUnaryOperator(java.lang.Object):
    def andThen(self, after: LongUnaryOperator, /) -> LongUnaryOperator: ...
    def applyAsLong(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...
    def compose(self, before: LongUnaryOperator, /) -> LongUnaryOperator: ...
    @staticmethod
    def identity() -> LongUnaryOperator: ...

_ObjDoubleConsumer__T = typing.TypeVar('_ObjDoubleConsumer__T')  # <T>
class ObjDoubleConsumer(java.lang.Object, typing.Generic[_ObjDoubleConsumer__T]):
    def accept(self, arg1: _ObjDoubleConsumer__T, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...

_ObjIntConsumer__T = typing.TypeVar('_ObjIntConsumer__T')  # <T>
class ObjIntConsumer(java.lang.Object, typing.Generic[_ObjIntConsumer__T]):
    def accept(self, arg1: _ObjIntConsumer__T, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

_ObjLongConsumer__T = typing.TypeVar('_ObjLongConsumer__T')  # <T>
class ObjLongConsumer(java.lang.Object, typing.Generic[_ObjLongConsumer__T]):
    def accept(self, arg1: _ObjLongConsumer__T, arg2: int | java.jlong | java.lang.Long, /) -> None: ...

_Predicate__T = typing.TypeVar('_Predicate__T')  # <T>
class Predicate(java.lang.Object, typing.Generic[_Predicate__T]):
    def and_(self, other: Predicate[_Predicate__T], /) -> Predicate[_Predicate__T]: ...
    @staticmethod
    def isEqual(targetRef: java.lang.Object | int | bool | float | str, /) -> Predicate[java.lang.Object]: ...
    def negate(self) -> Predicate[_Predicate__T]: ...
    _not___T = typing.TypeVar('_not___T')  # <T>
    @staticmethod
    def not_(target: Predicate[_not___T], /) -> Predicate[_not___T]: ...
    def or_(self, other: Predicate[_Predicate__T], /) -> Predicate[_Predicate__T]: ...
    def test(self, arg1: _Predicate__T, /) -> bool: ...

_Supplier__T = typing.TypeVar('_Supplier__T')  # <T>
class Supplier(java.lang.Object, typing.Generic[_Supplier__T]):
    def get(self) -> _Supplier__T: ...

_ToDoubleBiFunction__T = typing.TypeVar('_ToDoubleBiFunction__T')  # <T>
_ToDoubleBiFunction__U = typing.TypeVar('_ToDoubleBiFunction__U')  # <U>
class ToDoubleBiFunction(java.lang.Object, typing.Generic[_ToDoubleBiFunction__T, _ToDoubleBiFunction__U]):
    def applyAsDouble(self, arg1: _ToDoubleBiFunction__T, arg2: _ToDoubleBiFunction__U, /) -> float: ...

_ToDoubleFunction__T = typing.TypeVar('_ToDoubleFunction__T')  # <T>
class ToDoubleFunction(java.lang.Object, typing.Generic[_ToDoubleFunction__T]):
    def applyAsDouble(self, arg1: _ToDoubleFunction__T, /) -> float: ...

_ToIntBiFunction__T = typing.TypeVar('_ToIntBiFunction__T')  # <T>
_ToIntBiFunction__U = typing.TypeVar('_ToIntBiFunction__U')  # <U>
class ToIntBiFunction(java.lang.Object, typing.Generic[_ToIntBiFunction__T, _ToIntBiFunction__U]):
    def applyAsInt(self, arg1: _ToIntBiFunction__T, arg2: _ToIntBiFunction__U, /) -> int: ...

_ToIntFunction__T = typing.TypeVar('_ToIntFunction__T')  # <T>
class ToIntFunction(java.lang.Object, typing.Generic[_ToIntFunction__T]):
    def applyAsInt(self, arg1: _ToIntFunction__T, /) -> int: ...

_ToLongBiFunction__T = typing.TypeVar('_ToLongBiFunction__T')  # <T>
_ToLongBiFunction__U = typing.TypeVar('_ToLongBiFunction__U')  # <U>
class ToLongBiFunction(java.lang.Object, typing.Generic[_ToLongBiFunction__T, _ToLongBiFunction__U]):
    def applyAsLong(self, arg1: _ToLongBiFunction__T, arg2: _ToLongBiFunction__U, /) -> int: ...

_ToLongFunction__T = typing.TypeVar('_ToLongFunction__T')  # <T>
class ToLongFunction(java.lang.Object, typing.Generic[_ToLongFunction__T]):
    def applyAsLong(self, arg1: _ToLongFunction__T, /) -> int: ...

_UnaryOperator__T = typing.TypeVar('_UnaryOperator__T')  # <T>
class UnaryOperator(Function[_UnaryOperator__T, _UnaryOperator__T], typing.Generic[_UnaryOperator__T]):
    @staticmethod
    def identity() -> UnaryOperator[java.lang.Object]: ...



import typing

import java.lang
import javax.xml.transform
import org.xml.sax
import org.xml.sax.ext

class SAXResult(javax.xml.transform.Result):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, handler: org.xml.sax.ContentHandler, /) -> None: ...
    def getHandler(self) -> org.xml.sax.ContentHandler: ...
    def getLexicalHandler(self) -> org.xml.sax.ext.LexicalHandler: ...
    def getSystemId(self) -> str: ...
    def setHandler(self, handler: org.xml.sax.ContentHandler, /) -> None: ...
    def setLexicalHandler(self, handler: org.xml.sax.ext.LexicalHandler, /) -> None: ...
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...

class SAXSource(javax.xml.transform.Source):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, inputSource: org.xml.sax.InputSource, /) -> None: ...
    @typing.overload
    def __init__(self, reader: org.xml.sax.XMLReader, inputSource: org.xml.sax.InputSource, /) -> None: ...
    def getInputSource(self) -> org.xml.sax.InputSource: ...
    def getSystemId(self) -> str: ...
    def getXMLReader(self) -> org.xml.sax.XMLReader: ...
    def setInputSource(self, inputSource: org.xml.sax.InputSource, /) -> None: ...
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...
    def setXMLReader(self, reader: org.xml.sax.XMLReader, /) -> None: ...
    @staticmethod
    def sourceToInputSource(source: javax.xml.transform.Source, /) -> org.xml.sax.InputSource: ...

class SAXTransformerFactory(javax.xml.transform.TransformerFactory):
    FEATURE: typing.ClassVar[str] = ...
    FEATURE_XMLFILTER: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def newTemplatesHandler(self) -> TemplatesHandler: ...
    @typing.overload
    def newTransformerHandler(self) -> TransformerHandler: ...
    @typing.overload
    def newTransformerHandler(self, arg1: javax.xml.transform.Source, /) -> TransformerHandler: ...
    @typing.overload
    def newTransformerHandler(self, arg1: javax.xml.transform.Templates, /) -> TransformerHandler: ...
    @typing.overload
    def newXMLFilter(self, arg1: javax.xml.transform.Source, /) -> org.xml.sax.XMLFilter: ...
    @typing.overload
    def newXMLFilter(self, arg1: javax.xml.transform.Templates, /) -> org.xml.sax.XMLFilter: ...

class TemplatesHandler(org.xml.sax.ContentHandler):
    def getSystemId(self) -> str: ...
    def getTemplates(self) -> javax.xml.transform.Templates: ...
    def setSystemId(self, arg1: str | java.lang.String, /) -> None: ...

class TransformerHandler(org.xml.sax.ContentHandler, org.xml.sax.DTDHandler, org.xml.sax.ext.LexicalHandler):
    def getSystemId(self) -> str: ...
    def getTransformer(self) -> javax.xml.transform.Transformer: ...
    def setResult(self, arg1: javax.xml.transform.Result, /) -> None: ...
    def setSystemId(self, arg1: str | java.lang.String, /) -> None: ...
